@@ -194,6 +194,9 @@ public:
         options |= PLUGIN_OPTION_SEND_PITCHBEND;
         options |= PLUGIN_OPTION_SEND_ALL_SOUND_OFF;
         options |= PLUGIN_OPTION_SKIP_SENDING_NOTES;
+#if FLUIDSYNTH_VERSION_MAJOR >= 2
+        options |= PLUGIN_OPTION_SEND_NOTE_AFTERTOUCH;
+#endif
 
         return options;
     }
@@ -1332,10 +1335,7 @@ public:
 
                                     if (event.channel == pData->ctrlChannel)
                                     {
-                                        pData->postponeRtEvent(kPluginPostRtEventMidiProgramChange,
-                                                               true,
-                                                               static_cast<int32_t>(k),
-                                                               0, 0, 0.0f);
+                                        pData->postponeMidiProgramChangeRtEvent(true, k);
                                     }
 
                                     break;
@@ -1389,7 +1389,7 @@ public:
 
                             fluid_synth_noteoff(fSynth, event.channel, note);
 
-                            pData->postponeRtEvent(kPluginPostRtEventNoteOff, true, event.channel, note, 0, 0.0f);
+                            pData->postponeNoteOffRtEvent(true, event.channel, note);
                         }
                         break;
 
@@ -1401,19 +1401,21 @@ public:
 
                             fluid_synth_noteon(fSynth, event.channel, note, velo);
 
-                            pData->postponeRtEvent(kPluginPostRtEventNoteOn, true, event.channel, note, velo, 0.0f);
+                            pData->postponeNoteOnRtEvent(true, event.channel, note, velo);
                         }
                         break;
 
+#if FLUIDSYNTH_VERSION_MAJOR >= 2
                     case MIDI_STATUS_POLYPHONIC_AFTERTOUCH:
                         if (pData->options & PLUGIN_OPTION_SEND_NOTE_AFTERTOUCH)
                         {
-                            //const uint8_t note     = midiEvent.data[1];
-                            //const uint8_t pressure = midiEvent.data[2];
+                            const uint8_t note     = midiEvent.data[1];
+                            const uint8_t pressure = midiEvent.data[2];
 
-                            // not in fluidsynth API
+                            fluid_synth_key_pressure(fSynth, event.channel, note, pressure);
                         }
                         break;
+#endif
 
                     case MIDI_STATUS_CONTROL_CHANGE:
                         if (pData->options & PLUGIN_OPTION_SEND_CONTROL_CHANGES)
@@ -1756,6 +1758,10 @@ public:
             pData->options |= PLUGIN_OPTION_MAP_PROGRAM_CHANGES;
         if (isPluginOptionInverseEnabled(options, PLUGIN_OPTION_SKIP_SENDING_NOTES))
             pData->options |= PLUGIN_OPTION_SKIP_SENDING_NOTES;
+#if FLUIDSYNTH_VERSION_MAJOR >= 2
+        if (isPluginOptionEnabled(options, PLUGIN_OPTION_SEND_NOTE_AFTERTOUCH))
+            pData->options |= PLUGIN_OPTION_SEND_NOTE_AFTERTOUCH;
+#endif
 
         return true;
     }
