@@ -822,8 +822,6 @@ bool CarlaJackAppClient::handleRtData()
 
                     if (bridgeTimeInfo.validFlags & kPluginBridgeTimeInfoValidBBT)
                     {
-                        fServer.position.valid = JackPositionBBT;
-
                         fServer.position.bar  = bridgeTimeInfo.bar;
                         fServer.position.beat = bridgeTimeInfo.beat;
                         fServer.position.tick = static_cast<int32_t>(bridgeTimeInfo.tick + 0.5);
@@ -834,6 +832,13 @@ bool CarlaJackAppClient::handleRtData()
                         fServer.position.ticks_per_beat   = bridgeTimeInfo.ticksPerBeat;
                         fServer.position.beats_per_minute = bridgeTimeInfo.beatsPerMinute;
                         fServer.position.bar_start_tick   = bridgeTimeInfo.barStartTick;
+
+#ifdef JACK_TICK_DOUBLE
+                        fServer.position.tick_double = bridgeTimeInfo.tick;
+                        fServer.position.valid = static_cast<jack_position_bits_t>(JackPositionBBT|JackTickDouble);
+#else
+                        fServer.position.valid = JackPositionBBT;
+#endif
                     }
                     else
                     {
