@@ -2,7 +2,7 @@
   ==============================================================================
 
    This file is part of the JUCE library.
-   Copyright (c) 2017 - ROLI Ltd.
+   Copyright (c) 2020 - Raw Material Software Limited
 
    JUCE is an open source library subject to commercial or open-source
    licensing.
@@ -28,6 +28,8 @@ namespace juce
     A simple class to generate hash functions for some primitive types, intended for
     use with the HashMap class.
     @see HashMap
+
+    @tags{Core}
 */
 struct DefaultHashFunctions
 {
@@ -44,7 +46,9 @@ struct DefaultHashFunctions
     /** Generates a simple hash from a variant. */
     static int generateHash (const var& key, int upperLimit) noexcept       { return generateHash (key.toString(), upperLimit); }
     /** Generates a simple hash from a void ptr. */
-    static int generateHash (const void* key, int upperLimit) noexcept      { return generateHash ((pointer_sized_uint) key, upperLimit); }
+    static int generateHash (const void* key, int upperLimit) noexcept      { return generateHash ((uint64) (pointer_sized_uint) key, upperLimit); }
+    /** Generates a simple hash from a UUID. */
+    static int generateHash (const Uuid& key, int upperLimit) noexcept      { return generateHash (key.hash(), upperLimit); }
 };
 
 
@@ -89,6 +93,8 @@ struct DefaultHashFunctions
 
     @tparam HashFunctionType The class of hash function, which must be copy-constructible.
     @see CriticalSection, DefaultHashFunctions, NamedValueSet, SortedSet
+
+    @tags{Core}
 */
 template <typename KeyType,
           typename ValueType,
@@ -97,8 +103,8 @@ template <typename KeyType,
 class HashMap
 {
 private:
-    typedef typename TypeHelpers::ParameterType<KeyType>::type   KeyTypeParameter;
-    typedef typename TypeHelpers::ParameterType<ValueType>::type ValueTypeParameter;
+    using KeyTypeParameter   = typename TypeHelpers::ParameterType<KeyType>::type;
+    using ValueTypeParameter = typename TypeHelpers::ParameterType<ValueType>::type;
 
 public:
     //==============================================================================
@@ -114,7 +120,7 @@ public:
     */
     explicit HashMap (int numberOfSlots = defaultHashTableSize,
                       HashFunctionType hashFunction = HashFunctionType())
-       : hashFunctionToUse (hashFunction), totalNumItems (0)
+       : hashFunctionToUse (hashFunction)
     {
         hashSlots.insertMultiple (0, nullptr, numberOfSlots);
     }
@@ -140,7 +146,7 @@ public:
 
             while (h != nullptr)
             {
-                const ScopedPointer<HashEntry> deleter (h);
+                const std::unique_ptr<HashEntry> deleter (h);
                 h = h->nextEntry;
             }
 
@@ -197,7 +203,7 @@ public:
     }
 
     //==============================================================================
-    /** Returns true if the map contains an item with the specied key. */
+    /** Returns true if the map contains an item with the specified key. */
     bool contains (KeyTypeParameter keyToLookFor) const
     {
         const ScopedLockType sl (getLock());
@@ -237,7 +243,7 @@ public:
         {
             if (entry->key == keyToRemove)
             {
-                const ScopedPointer<HashEntry> deleter (entry);
+                const std::unique_ptr<HashEntry> deleter (entry);
 
                 entry = entry->nextEntry;
 
@@ -270,7 +276,7 @@ public:
             {
                 if (entry->value == valueToRemove)
                 {
-                    const ScopedPointer<HashEntry> deleter (entry);
+                    const std::unique_ptr<HashEntry> deleter (entry);
 
                     entry = entry->nextEntry;
 
@@ -348,7 +354,7 @@ public:
     inline const TypeOfCriticalSectionToUse& getLock() const noexcept      { return lock; }
 
     /** Returns the type of scoped lock to use for locking this array */
-    typedef typename TypeOfCriticalSectionToUse::ScopedLockType ScopedLockType;
+    using ScopedLockType = typename TypeOfCriticalSectionToUse::ScopedLockType;
 
 private:
     //==============================================================================
@@ -382,7 +388,7 @@ public:
         }
         @endcode
 
-        The order in which items are iterated bears no resemblence to the order in which
+        The order in which items are iterated bears no resemblance to the order in which
         they were originally added!
 
         Obviously as soon as you call any non-const methods on the original hash-map, any
@@ -455,7 +461,7 @@ public:
         int index;
 
         // using the copy constructor is ok, but you cannot assign iterators
-        Iterator& operator= (const Iterator&) JUCE_DELETED_FUNCTION;
+        Iterator& operator= (const Iterator&) = delete;
 
         JUCE_LEAK_DETECTOR (Iterator)
     };
@@ -473,7 +479,7 @@ private:
 
     HashFunctionType hashFunctionToUse;
     Array<HashEntry*> hashSlots;
-    int totalNumItems;
+    int totalNumItems = 0;
     TypeOfCriticalSectionToUse lock;
 
     int generateHashFor (KeyTypeParameter key, int numSlots) const
@@ -483,7 +489,7 @@ private:
         return hash;
     }
 
-    static inline HashEntry* getEntry (HashEntry* firstEntry, KeyType keyToLookFor) noexcept
+    static HashEntry* getEntry (HashEntry* firstEntry, KeyType keyToLookFor) noexcept
     {
         for (auto* entry = firstEntry; entry != nullptr; entry = entry->nextEntry)
             if (entry->key == keyToLookFor)
