@@ -275,7 +275,7 @@ protected:
         }
 
         if (fWasPlayingBefore)
-            if (! fMidiOut.play(frame, frames))
+            if (! fMidiOut.play(static_cast<uint32_t>(frame), frames))
                 fNeedsAllNotesOff = true;
 
         fLastFrame = frame;
@@ -321,12 +321,12 @@ protected:
     // -------------------------------------------------------------------
     // AbstractMidiPlayer calls
 
-    void writeMidiEvent(const uint8_t port, const long double timePosFrame, const RawMidiEvent* const event) override
+    void writeMidiEvent(const uint8_t port, const double timePosFrame, const RawMidiEvent* const event) override
     {
         NativeMidiEvent midiEvent;
 
         midiEvent.port    = port;
-        midiEvent.time    = uint32_t(timePosFrame);
+        midiEvent.time    = static_cast<uint32_t>(timePosFrame);
         midiEvent.size    = event->size;
         midiEvent.data[0] = event->data[0];
         midiEvent.data[1] = event->data[1];
@@ -406,7 +406,8 @@ private:
                 // const double time = track->getEventTime(i) * sampleRate;
                 CARLA_SAFE_ASSERT_CONTINUE(time >= 0.0);
 
-                fMidiOut.addRaw(static_cast<uint64_t>(time), midiMessage.getRawData(), static_cast<uint8_t>(dataSize));
+                fMidiOut.addRaw(static_cast<uint32_t>(time + 0.5),
+                                midiMessage.getRawData(), static_cast<uint8_t>(dataSize));
             }
         }
 
