@@ -32,6 +32,7 @@
 #include "lv2/units.h"
 #include "lv2/urid.h"
 #include "lv2/worker.h"
+#include "lv2/inline-display.h"
 #include "lv2/lv2_external_ui.h"
 #include "lv2/lv2_programs.h"
 
@@ -196,14 +197,14 @@ static void writeManifestFile(PluginListManager& plm, const uint32_t microVersio
 
     text += "<http://kxstudio.sf.net/carla/file/audio>\n";
     text += "    a lv2:Parameter ;\n";
-    text += "    mod:fileTypes \"audiofiles,audioloops\" ;\n";
+    text += "    mod:fileTypes \"audioloop,audiorecording,audiotrack\" ;\n";
     text += "    rdfs:label \"audio file\" ;\n";
     text += "    rdfs:range atom:Path .\n";
     text += "\n";
 
     text += "<http://kxstudio.sf.net/carla/file/midi>\n";
     text += "    a lv2:Parameter ;\n";
-    text += "    mod:fileTypes \"midi\" ;\n";
+    text += "    mod:fileTypes \"midisong\" ;\n";
     text += "    rdfs:label \"midi file\" ;\n";
     text += "    rdfs:range atom:Path .\n";
     text += "\n";
@@ -322,7 +323,12 @@ static void writePluginFile(const NativePluginDescriptor* const pluginDesc,
 
     // optional
     if (pluginDesc->hints & NATIVE_PLUGIN_IS_RTSAFE)
-        text += "    lv2:optionalFeature <" LV2_CORE__hardRTCapable "> ;\n\n";
+        text += "    lv2:optionalFeature <" LV2_CORE__hardRTCapable "> ;\n";
+    if (pluginDesc->hints & NATIVE_PLUGIN_HAS_INLINE_DISPLAY)
+        text += "    lv2:optionalFeature <" LV2_INLINEDISPLAY__queue_draw "> ;\n";
+    if ((pluginDesc->hints & NATIVE_PLUGIN_USES_STATE) || (pluginDesc->hints & NATIVE_PLUGIN_NEEDS_UI_OPEN_SAVE))
+        text += "    lv2:optionalFeature <" LV2_STATE__threadSafeRestore "> ;\n";
+    text += "\n";
 
     // required
     text += "    lv2:requiredFeature <" LV2_BUF_SIZE__boundedBlockLength "> ,\n";
@@ -330,6 +336,9 @@ static void writePluginFile(const NativePluginDescriptor* const pluginDesc,
     if (pluginDesc->hints & NATIVE_PLUGIN_NEEDS_FIXED_BUFFERS)
         text += "                        <" LV2_BUF_SIZE__fixedBlockLength "> ,\n";
 
+    if (pluginDesc->hints & NATIVE_PLUGIN_REQUESTS_IDLE)
+        text += "                        <" LV2_WORKER__schedule "> ,\n";
+
     text += "                        <" LV2_OPTIONS__options "> ,\n";
     text += "                        <" LV2_URID__map "> ;\n";
     text += "\n";
@@ -348,6 +357,9 @@ static void writePluginFile(const NativePluginDescriptor* const pluginDesc,
     if (pluginDesc->hints & NATIVE_PLUGIN_HAS_UI)
         text += "    lv2:extensionData <" LV2_WORKER__interface "> ;\n";
 
+    if (pluginDesc->hints & NATIVE_PLUGIN_HAS_INLINE_DISPLAY)
+        text += "    lv2:extensionData <" LV2_INLINEDISPLAY__interface "> ;\n";
+
     text += "\n";
 
     // -------------------------------------------------------------------
@@ -394,6 +406,8 @@ static void writePluginFile(const NativePluginDescriptor* const pluginDesc,
         {
             text += "        atom:supports <" LV2_TIME__Position "> ;\n";
         }
+        if (pluginDesc->hints & NATIVE_PLUGIN_NEEDS_UI_OPEN_SAVE)
+            text += "        atom:supports <" LV2_PATCH__Message "> ;\n";
 
         text += "        lv2:designation lv2:control ;\n";
         text += "        lv2:index " + String(portIndex++) + " ;\n";
@@ -472,6 +486,8 @@ static void writePluginFile(const NativePluginDescriptor* const pluginDesc,
 
         if (pluginDesc->midiOuts > 0)
             text += "        atom:supports <" LV2_MIDI__MidiEvent "> ;\n";
+        if (pluginDesc->hints & NATIVE_PLUGIN_NEEDS_UI_OPEN_SAVE)
+            text += "        atom:supports <" LV2_PATCH__Message "> ;\n";
 
         text += "        lv2:index " + String(portIndex++) + " ;\n";
 
