@@ -1,6 +1,6 @@
 /*
  * Carla Plugin UI
- * Copyright (C) 2014-2020 Filipe Coelho <falktx@falktx.com>
+ * Copyright (C) 2014-2021 Filipe Coelho <falktx@falktx.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -58,12 +58,14 @@ static int temporaryErrorHandler(Display*, XErrorEvent*)
 class X11PluginUI : public CarlaPluginUI
 {
 public:
-    X11PluginUI(Callback* const cb, const uintptr_t parentId, const bool isResizable) noexcept
-        : CarlaPluginUI(cb, isResizable),
+    X11PluginUI(Callback* const cb, const uintptr_t parentId,
+                const bool isStandalone, const bool isResizable, const bool canMonitorChildren) noexcept
+        : CarlaPluginUI(cb, isStandalone, isResizable),
           fDisplay(nullptr),
           fHostWindow(0),
           fChildWindow(0),
           fChildWindowConfigured(false),
+          fChildWindowMonitoring(isResizable || canMonitorChildren),
           fIsVisible(false),
           fFirstShow(true),
           fSetSizeCalledAtLeastOnce(false),
@@ -77,7 +79,10 @@ public:
         XSetWindowAttributes attr;
         carla_zeroStruct(attr);
 
-        attr.event_mask = KeyPressMask|KeyReleaseMask|FocusChangeMask|StructureNotifyMask|SubstructureNotifyMask;
+        attr.event_mask = KeyPressMask|KeyReleaseMask|FocusChangeMask;
+
+        if (fChildWindowMonitoring)
+            attr.event_mask |= StructureNotifyMask|SubstructureNotifyMask;
 
         fHostWindow = XCreateWindow(fDisplay, RootWindow(fDisplay, screen),
                                     0, 0, 300, 300, 0,
@@ -276,7 +281,7 @@ public:
 
                         fCallback->handlePluginUIResized(width, height);
                     }
-                    else if (event.xconfigure.window == fChildWindow && fChildWindow != 0)
+                    else if (fChildWindowMonitoring && event.xconfigure.window == fChildWindow && fChildWindow != 0)
                     {
                         nextWidth = event.xconfigure.width;
                         nextHeight = event.xconfigure.height;
@@ -308,13 +313,13 @@ public:
                 if (fChildWindow == 0)
                     fChildWindow = getChildWindow();
                 if (fChildWindow != 0)
-                    XSetInputFocus(fDisplay, fChildWindow, RevertToNone, CurrentTime);
+                    XSetInputFocus(fDisplay, fChildWindow, RevertToPointerRoot, CurrentTime);
                 break;
             }
 
             if (type != nullptr)
                 XFree(type);
-            else if (fEventProc != nullptr)
+            else if (fEventProc != nullptr && event.type != FocusIn && event.type != FocusOut)
                 fEventProc(&event);
         }
 
@@ -441,6 +446,7 @@ private:
     Window   fHostWindow;
     Window   fChildWindow;
     bool     fChildWindowConfigured;
+    bool     fChildWindowMonitoring;
     bool     fIsVisible;
     bool     fFirstShow;
     bool     fSetSizeCalledAtLeastOnce;
@@ -565,8 +571,8 @@ private:
 class CocoaPluginUI : public CarlaPluginUI
 {
 public:
-    CocoaPluginUI(Callback* const callback, const uintptr_t parentId, const bool isResizable) noexcept
-        : CarlaPluginUI(callback, isResizable),
+    CocoaPluginUI(Callback* const callback, const uintptr_t parentId, const bool isStandalone, const bool isResizable) noexcept
+        : CarlaPluginUI(callback, isStandalone, isResizable),
           fView(nullptr),
           fParentWindow(nullptr),
           fWindow(nullptr)
@@ -786,8 +792,8 @@ static LRESULT CALLBACK wndProc(HWND hwnd, UINT message, WPARAM wParam, LPARAM l
 class WindowsPluginUI : public CarlaPluginUI
 {
 public:
-    WindowsPluginUI(Callback* const cb, const uintptr_t parentId, const bool isResizable) noexcept
-        : CarlaPluginUI(cb, isResizable),
+    WindowsPluginUI(Callback* const cb, const uintptr_t parentId, const bool isStandalone, const bool isResizable) noexcept
+        : CarlaPluginUI(cb, isStandalone, isResizable),
           fWindow(nullptr),
           fChildWindow(nullptr),
           fParentWindow(nullptr),
@@ -1384,23 +1390,33 @@ bool CarlaPluginUI::tryTransientWinIdMatch(const uintptr_t pid, const char* cons
 // -----------------------------------------------------
 
 #ifdef HAVE_X11
-CarlaPluginUI* CarlaPluginUI::newX11(Callback* cb, uintptr_t parentId, bool isResizable)
+CarlaPluginUI* CarlaPluginUI::newX11(Callback* const cb,
+                                     const uintptr_t parentId,
+                                     const bool isStandalone,
+                                     const bool isResizable, 
+                                     const bool isLV2)
 {
-    return new X11PluginUI(cb, parentId, isResizable);
+    return new X11PluginUI(cb, parentId, isStandalone, isResizable, isLV2);
 }
 #endif
 
 #ifdef CARLA_OS_MAC
-CarlaPluginUI* CarlaPluginUI::newCocoa(Callback* cb, uintptr_t parentId, bool isResizable)
+CarlaPluginUI* CarlaPluginUI::newCocoa(Callback* const cb,
+                                       const uintptr_t parentId,
+                                       const bool isStandalone,
+                                       const bool isResizable)
 {
-    return new CocoaPluginUI(cb, parentId, isResizable);
+    return new CocoaPluginUI(cb, parentId, isStandalone, isResizable);
 }
 #endif
 
 #ifdef CARLA_OS_WIN
-CarlaPluginUI* CarlaPluginUI::newWindows(Callback* cb, uintptr_t parentId, bool isResizable)
+CarlaPluginUI* CarlaPluginUI::newWindows(Callback* const cb,
+                                         const uintptr_t parentId,
+                                         const bool isStandalone,
+                                         const bool isResizable)
 {
-    return new WindowsPluginUI(cb, parentId, isResizable);
+    return new WindowsPluginUI(cb, parentId, isStandalone, isResizable);
 }
 #endif
 
